Module build_manager

Module build_manager 

Auxiliary and dependency builder. Extendable to custom builds.

Structs

BuildManager
Deduplicates builds

Traits

Build
A build shared between all tests of the same BuildManager

Type Aliases

NewJob
Type of closure that is used to run individual tests.